@@ -18,13 +18,14 @@
 #
 #    (C) 2005 Nicolas Évrard <nicoe@altern.org>
 
-__revision__ = "$Id: gnomolicious.py,v 1.8 2005/02/03 14:44:25 nicoe Exp $"
+__revision__ = "$Id: gnomolicious.py,v 1.12 2005/03/11 11:45:28 nicoe Exp $"
 
 import os.path
 import re
 import logging
 import urllib
 import ConfigParser
+import time
 from time import time as now
 
 import pygtk
@@ -67,7 +68,7 @@ class GnomoliciousConfiguration(object):
                 self.gconf.get_int(self.GCONF_PATH + '/pop_tag_num')
         self.gconf.notify_add(self.GCONF_PATH, self.changed_conf)
         
-    def changed_conf(self, cid, entry, cdata = None):
+    def changed_conf(self, cid, cnxn_id, entry, data):
         key, value = entry.key, entry.value
         keyname = key.split('/')[-1]
         self.conf[keyname] = value
@@ -221,6 +222,11 @@ class GnomoliciousApplet(gnome.applet.Applet):
             'updatetime' : wT.get_widget('entry_updatetime'),
             'maxpoptag' : wT.get_widget('entry_numpoptag'),
             }
+
+        self.update_dialog = gtk.MessageDialog(
+                    parent = None,
+                    type = gtk.MESSAGE_INFO,
+                    message_format = _('Updating the list of your tags'))
         
         wT.signal_autoconnect(self)
 
@@ -370,14 +376,23 @@ class GnomoliciousApplet(gnome.applet.Applet):
         tags = self.postwin.entries['tags'].get_text()
         buff = self.postwin.entries['ext'].get_buffer()
         ext = buff.get_text(buff.get_start_iter(), buff.get_end_iter())
-        logger.info('URL: %s' % url)
-        logger.info('Tags: %s' % tags)
-        delicious.add(self.conf.username,
-                      self.conf.password, url, desc, ext, tags)
-        logger.info('Posting done')
-        self.postwin.hide()
-        self.clear_postwin()
-        return gtk.TRUE
+        if url and desc and tags:
+            logger.info('Posting URL: %s' % url)
+            delicious.add(self.conf.username,
+                          self.conf.password, url, desc, ext, tags)
+            logger.info('Posting done')
+            self.postwin.hide()
+            self.clear_postwin()
+        else:
+            warn = gtk.MessageDialog(
+                    parent = self.postwin,
+                    flags = gtk.DIALOG_MODAL,
+                    type = gtk.MESSAGE_WARNING,
+                    buttons = gtk.BUTTONS_CLOSE)
+            warn.set_markup(_('Nothing to post ! Make sure the URL, Description and Tags entries are not empty.'))
+            warn.run()
+            warn.destroy()
+        return True
 
     def on_setpref(self, evt, data=None):
         self.conf.username = self.prefwin.entries['username'].get_text()
@@ -391,35 +406,35 @@ class GnomoliciousApplet(gnome.applet.Applet):
                 self.prefwin.entries['maxpoptag'].get_value_as_int()
 
         self.prefwin.hide()
-        return gtk.TRUE
+        return True
 
     def on_postwin_delete_event(self, widget, evt):
         self.postwin.hide()
         self.clear_postwin()
-        return gtk.TRUE
+        return True
 
     def on_prefwin_delete_event(self, widget, evt):
         self.prefwin.hide()
-        return gtk.TRUE
+        return True
     
     def on_cancelpost(self, evt, data=None):
         self.postwin.hide()
         self.clear_postwin()
-        return gtk.TRUE
+        return True
 
     def on_match_selected(self, completion, model, cursor):
         match = model[cursor][0]
         etokens = self.postwin.entries['tags'].get_text().split()
         etokens[-1] = match
         self.postwin.entries['tags'].set_text(' '.join(etokens))
-        return gtk.TRUE
+        return True
 
     def on_postwin_tags(self, widget):
         tags = self.postwin.entries['tags'].get_text().split()
         for tag, btn in self.populartags_buttons.items():
             btn.set_active(tag in tags)
-        return gtk.TRUE
+        return True
 
     def on_register_clicked(self, evt, data=None):
         gnome.url_show('http://del.icio.us/register')
-        return gtk.TRUE
+        return True
